@@ -265,7 +265,7 @@ class NumberValueInterface(CopyInterface):
         result : Number
             True division result value.
         """
-        from apyscript.type.number import Number
+        from apyscript.type import Number
         result: Number = Number(value=self)
         if isinstance(other, NumberValueInterface):
             value: Union[int, float, Any] = result._value / other.value
@@ -310,7 +310,7 @@ class NumberValueInterface(CopyInterface):
         result : Int
             Floor division result value.
         """
-        from apyscript.type.int import Int
+        from apyscript.type import Int
         result: Int = Int(value=self)
         if isinstance(other, NumberValueInterface):
             value: Union[int, float, Any] = self._value // other.value
@@ -411,15 +411,37 @@ class NumberValueInterface(CopyInterface):
 
     def __str__(self) -> str:
         """
-        String cast method.
+        String conversion method.
 
         Returns
         -------
         string : str
-            Casted value string.
+            Converted value string.
         """
         return str(self.value)
 
+    def __int__(self) -> int:
+        """
+        Integer conversion method.
+
+        Returns
+        -------
+        integer : int
+            Converted integer value.
+        """
+        return int(self.value)
+
+    def __float__(self) -> float:
+        """
+        Float conversion method.
+
+        Returns
+        -------
+        float_ : float
+            Converted float value.
+        """
+        return float(self.value)
+
     def __eq__(self, other: Any) -> bool:
         """
         Equal comparison method.
